<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Phunk
 */

get_header();

$layout = phunk_blog_layout();

if ( 'layout-default' === $layout ) {
	$cols = 'col75';
} elseif ( 'layout-3cols' === $layout ) {
	$cols = '';
} elseif ( 'layout-1cols-2sb' === $layout ) {
	$cols = 'col50';
}

?>

	<?php
	if ( 'layout-1cols-2sb' === $layout ) {
		get_sidebar( 'left' );
	}
	?>

	<div id="primary" class="content-area <?php echo $cols; ?> col-t-100">
		<main id="main" class="site-main">

		<?php
		if ( have_posts() ) :

			if ( is_home() && ! is_front_page() ) :
				?>
				<header>
					<h1 class="page-title screen-reader-text"><?php single_post_title(); ?></h1>
				</header>
				<?php
			endif; ?>

			<div class="grid-layout clear">
			<?php
			while ( have_posts() ) :
				the_post();

				/*
				 * Include the Post-Type-specific template for the content.
				 * If you want to override this in a child theme, then include a file
				 * called content-___.php (where ___ is the Post Type name) and that will be used instead.
				 */
				get_template_part( 'template-parts/content', get_post_type() );

			endwhile; ?>
			</div>
			<?php
			the_posts_pagination( 
				array( 
					'mid_size' => 2,
					'prev_text' => '&lt;',
					'next_text' => '&gt;', 
				) 
			);
			
		else :

			get_template_part( 'template-parts/content', 'none' );

		endif;
		?>

		</main><!-- #main -->
	</div><!-- #primary -->

<?php
if ( 'layout-3cols' !== $layout ) {
	get_sidebar();
}
get_footer();
