<?php
/**
 * Phunk Theme Customizer
 *
 * @package Phunk
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function phunk_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
    $wp_customize->get_section( 'colors' )->title = esc_attr__( 'General', 'phunk' );
    $wp_customize->get_section( 'colors' )->panel = 'phunk_panel_colors';
    $wp_customize->get_section( 'colors' )->priority = '10';
    $wp_customize->get_section( 'header_image' )->panel = 'phunk_panel_header';



	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'phunk_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'phunk_customize_partial_blogdescription',
		) );
	}
}
add_action( 'customize_register', 'phunk_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function phunk_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function phunk_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function phunk_customize_preview_js() {
	wp_enqueue_script( 'phunk-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20181112', true );
}
add_action( 'customize_preview_init', 'phunk_customize_preview_js' );

/**
 * Kirki files
 */
require get_template_directory() . '/inc/customizer/kirki/include-kirki.php';
require get_template_directory() . '/inc/customizer/kirki/class-sg-kirki.php';

/**
 * Config
 */
Phunk_Kirki::add_config( 'phunk', array(
	'capability'    => 'edit_theme_options',
	'option_type'   => 'theme_mod',
) );

/**
 * Load customizer options files
 */
if ( class_exists( 'Kirki' ) ) {
	require get_template_directory() . '/inc/customizer/sections/options-header.php';
	require get_template_directory() . '/inc/customizer/sections/options-fonts.php';
	require get_template_directory() . '/inc/customizer/sections/options-blog.php';
	require get_template_directory() . '/inc/customizer/sections/options-colors.php';
	require get_template_directory() . '/inc/customizer/sections/options-footer.php';
}