/**
 * File customizer.js.
 *
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

( function( $ ) {

	// Site title and description.
	wp.customize( 'blogname', function( value ) {
		value.bind( function( to ) {
			$( '.site-title a' ).text( to );
		} );
	} );
	wp.customize( 'blogdescription', function( value ) {
		value.bind( function( to ) {
			$( '.site-description' ).text( to );
		} );
	} );

	// Header text color.
	wp.customize( 'header_textcolor', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-title, .site-description' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-title, .site-description' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-title a, .site-description' ).css( {
					'color': to
				} );
			}
		} );
	} );


	// Single post layout
	wp.customize( 'post_layout', function( value ) {
		value.bind( function( to ) {
			if ( 'layout-no-sidebar' === to ) {
				$( '.single-post .widget-area' ).css( {
					'display': 'none',
				} );	
				$( '.single-post .content-area' ).addClass( 'single-post-no-sidebar' );			
			} else {
				$( '.single-post .widget-area' ).css( {
					'display': 'block',
				} );	
				$( '.single-post .content-area' ).removeClass( 'single-post-no-sidebar' );	
			}
		} );
	} );

	// Single post navigation
	wp.customize( 'post_navigation', function( value ) {
		value.bind( function( to ) {
			if ( 'floating' === to ) {
				$( '.single-post .post-navigation' ).removeClass( 'floating regular' ).addClass( 'floating' );	

			} else {
				$( '.single-post .post-navigation' ).removeClass( 'floating regular' ).addClass( 'regular' );	
			}
		} );
	} );	

	// Reversed header
	wp.customize( 'reverse_entry_header', function( value ) {
		value.bind( function( to ) {
			if ( true === to ) {
				$( '.single-post .entry-header' ).addClass( 'reversed-header' );
			} else {
				$( '.single-post .entry-header' ).removeClass( 'reversed-header' );	
			}
		} );
	} );

} )( jQuery );
